@@ -1,4 +1,12 @@
-"""Matrix Gallery for Multigrid Solvers"""
+"""Matrix gallery of model problems.
+
+Functions
+=========
+    - poisson() : Poisson problem using Finite Differences
+    - linear_elasticity() : Linear Elasticity using Finite Elements
+    - stencil_grid() : General stencil generation from 1D, 2D, and 3D
+    - diffusion_stencil_2d() : 2D rotated anisotropic FE/FD stencil
+"""
 
 from . import elasticity
 from . import laplacian
@@ -26,13 +34,3 @@ __all__ = [
     'sprand',
     'demo',
 ]
-
-__doc__ += """Matrix Gallery for Multigrid Solvers.
-
-Functions
-=========
-    - poisson() : Poisson problem using Finite Differences
-    - linear_elasticity() : Linear Elasticity using Finite Elements
-    - stencil_grid() : General stencil generation from 1D, 2D, and 3D
-    - diffusion_stencil_2d() : 2D rotated anisotropic FE/FD stencil
-"""
